@@ -49,11 +49,11 @@ class League(BaseLeague):
     def _fetch_draft(self):
         '''Creates list of Pick objects from the leagues draft'''
         data = self.espn_request.get_league_draft()
-        
+
         # League has not drafted yet
         if not data['draftDetail']['drafted']:
             return
-        
+
         picks = data['draftDetail']['picks']
         for pick in picks:
             team = self.get_team_data(pick['teamId'])
@@ -67,7 +67,7 @@ class League(BaseLeague):
             keeper_status = pick['keeper']
 
             self.draft.append(Pick(team, playerId, playerName, round_num, round_pick, bid_amount, keeper_status))
-    
+
     def _get_positional_ratings(self, week: int):
         params = {
             'view': 'mPositionalRatings',
@@ -101,7 +101,7 @@ class League(BaseLeague):
         team_roster = {}
         for team in data['teams']:
             team_roster[team['id']] = team['roster']
-        
+
         for team in self.teams:
             roster = team_roster[team.team_id]
             team._fetch_roster(roster, self.year)
@@ -113,7 +113,7 @@ class League(BaseLeague):
     def top_scorer(self) -> Team:
         most_pf = sorted(self.teams, key=lambda x: x.points_for, reverse=True)
         return most_pf[0]
-    
+
     def least_scorer(self) -> Team:
         least_pf = sorted(self.teams, key=lambda x: x.points_for, reverse=False)
         return least_pf[0]
@@ -129,7 +129,7 @@ class League(BaseLeague):
         top_scored_tup = [(i, j) for (i, j) in zip(self.teams, top_week_points)]
         top_tup = sorted(top_scored_tup, key=lambda tup: int(tup[1]), reverse=True)
         return top_tup[0]
-    
+
     def least_scored_week(self) -> Tuple[Team, int]:
         least_week_points = []
         for team in self.teams:
@@ -143,7 +143,7 @@ class League(BaseLeague):
             if team_id == team.team_id:
                 return team
         return None
-    
+
     def recent_activity(self, size: int = 25, msg_type: str = None) -> List[Activity]:
         '''Returns a list of recent league activities (Add, Drop, Trade)'''
         if self.year < 2019:
@@ -155,7 +155,7 @@ class League(BaseLeague):
         params = {
             'view': 'kona_league_communication'
         }
-        
+
         filters = {"topics":{"filterType":{"value":["ACTIVITY_TRANSACTIONS"]},"limit":size,"limitPerMessageSet":{"value":25},"offset":0,"sortMessageDate":{"sortPriority":1,"sortAsc":False},"sortFor":{"sortPriority":2,"sortAsc":False},"filterIncludeMessageTypeIds":{"value":msg_types}}}
         headers = {'x-fantasy-filter': json.dumps(filters)}
         data = self.espn_request.league_get(extend='/communication/', params=params, headers=headers)
@@ -183,7 +183,7 @@ class League(BaseLeague):
                     matchup.home_team = team
                 elif matchup.away_team == team.team_id:
                     matchup.away_team = team
-        
+
         return matchups
 
     def box_scores(self, week: int = None) -> List[BoxScore]:
@@ -191,22 +191,28 @@ class League(BaseLeague):
         Should only be used with most recent season'''
         if self.year < 2019:
             raise Exception('Cant use box score before 2019')
-        if not week or week > self.current_week:
-            week = self.current_week
+        matchup_period = self.currentMatchupPeriod
+        scoring_period = self.current_week
+        if week and week <= self.current_week:
+            scoring_period = week
+            for matchup_id in self.settings.matchup_periods:
+              if week in self.settings.matchup_periods[matchup_id]:
+                matchup_period = matchup_id
+                break
 
         params = {
             'view': ['mMatchupScore', 'mScoreboard'],
-            'scoringPeriodId': week,
+            'scoringPeriodId': scoring_period,
         }
-        
-        filters = {"schedule":{"filterMatchupPeriodIds":{"value":[week]}}}
+
+        filters = {"schedule":{"filterMatchupPeriodIds":{"value":[matchup_period]}}}
         headers = {'x-fantasy-filter': json.dumps(filters)}
         data = self.espn_request.league_get(params=params, headers=headers)
 
         schedule = data['schedule']
-        pro_schedule = self._get_pro_schedule(week)
-        positional_rankings = self._get_positional_ratings(week)
-        box_data = [BoxScore(matchup, pro_schedule, positional_rankings, week, self.year) for matchup in schedule]
+        pro_schedule = self._get_pro_schedule(scoring_period)
+        positional_rankings = self._get_positional_ratings(scoring_period)
+        box_data = [BoxScore(matchup, pro_schedule, positional_rankings, scoring_period, self.year) for matchup in schedule]
 
         for team in self.teams:
             for matchup in box_data:
@@ -215,7 +221,7 @@ class League(BaseLeague):
                 elif matchup.away_team == team.team_id:
                     matchup.away_team = team
         return box_data
-        
+
     def power_rankings(self, week: int=None):
         '''Return power rankings for any week'''
 
@@ -227,7 +233,7 @@ class League(BaseLeague):
                               reverse=False)
 
         for team in teams_sorted:
-            wins = [0]*len(teams_sorted) 
+            wins = [0]*len(teams_sorted)
             for mov, opponent in zip(team.mov[:week], team.schedule[:week]):
                 opp = teams_sorted.index(opponent)
                 if mov > 0:
@@ -245,14 +251,14 @@ class League(BaseLeague):
             raise Exception('Cant use free agents before 2019')
         if not week:
             week = self.current_week
-        
+
         slot_filter = []
         if position and position in POSITION_MAP:
             slot_filter = [POSITION_MAP[position]]
         if position_id:
             slot_filter.append(position_id)
 
-        
+
         params = {
             'view': 'kona_player_info',
             'scoringPeriodId': week,
@@ -280,7 +286,7 @@ class League(BaseLeague):
         headers = {'x-fantasy-filter': json.dumps(filters)}
 
         data = self.espn_request.league_get(params=params, headers=headers)
-        
+
         if len(data['players']) > 0:
             return Player(data['players'][0], self.year)
 
